@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 
 # Common variables and functions
 
@@ -8,19 +8,19 @@ SCREEN_SESSION=freebsd
 SSH_PORT=10022
 
 FREEBSD_VERSION="12.1"
-IMAGE_NAME=FreeBSD-${FREEBSD_VERSION}-RELEASE-amd64.raw
+IMAGE_NAME=FreeBSD-$FREEBSD_VERSION-RELEASE-amd64.raw
 # https://download.freebsd.org/ftp/releases/VM-IMAGES/12.1-RELEASE/amd64/Latest/
 IMAGE_SHA512="a65da6260f5f894fc86fbe1f27dad7800906da7cffaa5077f82682ab74b6dd46c4ce87158c14b726d74ca3c6d611bea3bb336164da3f1cb990550310b110da22"
 
 RUN() {
-  ssh -t -o ConnectionAttempts=120 -o ConnectTimeout=2 -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no root@localhost -p $SSH_PORT "$@"
+  ssh -t -o ConnectionAttempts=120 -o ConnectTimeout=2 -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no root@localhost -p "$SSH_PORT" "$@"
 }
 
 start_vm() {
-  screen -d -m qemu-system-x86_64 -curses -m 2048 -smp $NPROC -net user,hostfwd=tcp::${SSH_PORT}-:22 -net nic "$IMAGE_NAME"
+  screen -d -m qemu-system-x86_64 -curses -m 2048 -smp "$NPROC" -net user,hostfwd=tcp::"$SSH_PORT"-:22 -net nic "$IMAGE_NAME"
 
   # Wait for ssh to start listening on the port
-  while ! echo "exit" | nc localhost ${SSH_PORT} | grep 'OpenSSH'; do
+  while ! echo "exit" | nc localhost "$SSH_PORT" | grep 'OpenSSH'; do
     sleep 5
   done
 
@@ -29,8 +29,7 @@ start_vm() {
   RUN last
 }
 
-stop_vm()
-{
+stop_vm() {
   # Turn it off
   # We use this contraption because for some reason `shutdown -h now` and
   # `poweroff` result in FreeBSD not shutting down on Travis (they work on my
