@@ -1,20 +1,20 @@
-#!/bin/sh
+#!/bin/bash
 
 ACTION="$1"
 
 set -eu
 
 CACHEDIR="$HOME/cache"
-NPROC=`nproc`
+NPROC=$(nproc)
 
 travis_install() {
   cd other/docker/windows
 
   docker build \
-    --build-arg SUPPORT_ARCH_i686=$i686 \
-    --build-arg SUPPORT_ARCH_x86_64=$x86_64 \
+    --build-arg SUPPORT_ARCH_i686="$i686" \
+    --build-arg SUPPORT_ARCH_x86_64="$x86_64" \
     --build-arg SUPPORT_TEST=true \
-    -t toxcore-$WINDOWS_ARCH \
+    -t toxcore-"$WINDOWS_ARCH" \
     .
 }
 
@@ -27,8 +27,8 @@ travis_script() {
 
   docker run \
     -e ALLOW_TEST_FAILURE=true \
-    -e ENABLE_ARCH_i686=$i686 \
-    -e ENABLE_ARCH_x86_64=$x86_64 \
+    -e ENABLE_ARCH_i686="$i686" \
+    -e ENABLE_ARCH_x86_64="$x86_64" \
     -e ENABLE_TEST=true \
     -e EXTRA_CMAKE_FLAGS="-DBOOTSTRAP_DAEMON=OFF -DMIN_LOGGER_LEVEL=DEBUG -DTEST_TIMEOUT_SECONDS=90 -DAUTOTEST=ON" \
     -e CMAKE_C_FLAGS="$C_FLAGS" \
@@ -38,7 +38,7 @@ travis_script() {
     -v "$PWD:/toxcore" \
     -v "$PWD/result:/prefix" \
     --rm \
-    toxcore-$WINDOWS_ARCH
+    toxcore-"$WINDOWS_ARCH"
 }
 
 if [ "-z" "$ACTION" ]; then
