@@ -1,10 +1,13 @@
-#!/bin/sh
+#!/bin/bash
 
-add_config_flag() { CONFIG_FLAGS="$CONFIG_FLAGS $@";    }
-add_c_flag()      { C_FLAGS="$C_FLAGS $@";              }
-add_cxx_flag()    { CXX_FLAGS="$CXX_FLAGS $@";          }
-add_ld_flag()     { LD_FLAGS="$LD_FLAGS $@";            }
-add_flag()        { add_c_flag "$@"; add_cxx_flag "$@"; }
+add_config_flag() { CONFIG_FLAGS+=("$@"); }
+add_c_flag() { C_FLAGS="$C_FLAGS $@"; }
+add_cxx_flag() { CXX_FLAGS="$CXX_FLAGS $@"; }
+add_ld_flag() { LD_FLAGS="$LD_FLAGS $@"; }
+add_flag() {
+  add_c_flag "$@"
+  add_cxx_flag "$@"
+}
 
 export LD_LIBRARY_PATH="$CACHEDIR/lib"
 export PKG_CONFIG_PATH="$CACHEDIR/lib/pkgconfig"
@@ -13,7 +16,7 @@ export PKG_CONFIG_PATH="$CACHEDIR/lib/pkgconfig"
 # and friends here (we unset them below), because they influence config tests
 # such as ./configure and cmake tests. Our warning flags break those tests, so
 # we can't add them globally here.
-CONFIG_FLAGS=""
+CONFIG_FLAGS=()
 C_FLAGS=""
 CXX_FLAGS=""
 LD_FLAGS=""
