@@ -48,12 +48,13 @@ static uint16_t ports[NUM_PORTS] = {13215, 33445, 25643};
 START_TEST(test_basic)
 {
     Mono_Time *mono_time = mono_time_new();
+    Logger *logger = logger_new();
 
     // Attempt to create a new TCP_Server instance.
     uint8_t self_public_key[CRYPTO_PUBLIC_KEY_SIZE];
     uint8_t self_secret_key[CRYPTO_SECRET_KEY_SIZE];
     crypto_new_keypair(self_public_key, self_secret_key);
-    TCP_Server *tcp_s = new_TCP_server(USE_IPV6, NUM_PORTS, ports, self_secret_key, nullptr);
+    TCP_Server *tcp_s = new_TCP_server(logger, USE_IPV6, NUM_PORTS, ports, self_secret_key, nullptr);
     ck_assert_msg(tcp_s != nullptr, "Failed to create a TCP relay server.");
     ck_assert_msg(tcp_server_listen_count(tcp_s) == NUM_PORTS,
                   "Failed to bind a TCP relay server to all %d attempted ports.", NUM_PORTS);
@@ -122,7 +123,8 @@ START_TEST(test_basic)
     memcpy(f_nonce_r, response_plain + CRYPTO_SHARED_KEY_SIZE, CRYPTO_NONCE_SIZE);
 
     // Building a request
-    uint8_t r_req_p[1 + CRYPTO_PUBLIC_KEY_SIZE] = {0};
+    uint8_t r_req_p[1 + CRYPTO_PUBLIC_KEY_SIZE];
+    r_req_p[0] = TCP_PACKET_ROUTING_REQUEST;
     memcpy(r_req_p + 1, f_public_key, CRYPTO_PUBLIC_KEY_SIZE);
     uint8_t r_req[2 + 1 + CRYPTO_PUBLIC_KEY_SIZE + CRYPTO_MAC_SIZE];
     uint16_t size = 1 + CRYPTO_PUBLIC_KEY_SIZE + CRYPTO_MAC_SIZE;
@@ -162,7 +164,8 @@ START_TEST(test_basic)
     ck_assert_msg(ret != -1, "Failed to decrypt the TCP server's response.");
     increment_nonce(f_nonce_r);
 
-    ck_assert_msg(packet_resp_plain[0] == 1, "Server sent the wrong packet id: %u", packet_resp_plain[0]);
+    ck_assert_msg(packet_resp_plain[0] == TCP_PACKET_ROUTING_RESPONSE, "Server sent the wrong packet id: %u",
+                  packet_resp_plain[0]);
     ck_assert_msg(packet_resp_plain[1] == 0, "Server did not refuse the connection.");
     ck_assert_msg(public_key_cmp(packet_resp_plain + 2, f_public_key) == 0, "Server sent the wrong public key.");
 
@@ -170,6 +173,7 @@ START_TEST(test_basic)
     kill_sock(sock);
     kill_TCP_server(tcp_s);
 
+    logger_kill(logger);
     mono_time_free(mono_time);
 }
 END_TEST
@@ -185,6 +189,7 @@ struct sec_TCP_con {
 static struct sec_TCP_con *new_TCP_con(TCP_Server *tcp_s, Mono_Time *mono_time)
 {
     struct sec_TCP_con *sec_c = (struct sec_TCP_con *)malloc(sizeof(struct sec_TCP_con));
+    ck_assert(sec_c != nullptr);
     Socket sock = net_socket(net_family_ipv6, TOX_SOCK_STREAM, TOX_PROTO_TCP);
 
     IP_Port ip_port_loopback;
@@ -271,11 +276,12 @@ static int read_packet_sec_TCP(struct sec_TCP_con *con, uint8_t *data, uint16_t
 START_TEST(test_some)
 {
     Mono_Time *mono_time = mono_time_new();
+    Logger *logger = logger_new();
 
     uint8_t self_public_key[CRYPTO_PUBLIC_KEY_SIZE];
     uint8_t self_secret_key[CRYPTO_SECRET_KEY_SIZE];
     crypto_new_keypair(self_public_key, self_secret_key);
-    TCP_Server *tcp_s = new_TCP_server(USE_IPV6, NUM_PORTS, ports, self_secret_key, nullptr);
+    TCP_Server *tcp_s = new_TCP_server(logger, USE_IPV6, NUM_PORTS, ports, self_secret_key, nullptr);
     ck_assert_msg(tcp_s != nullptr, "Failed to create TCP relay server");
     ck_assert_msg(tcp_server_listen_count(tcp_s) == NUM_PORTS, "Failed to bind to all ports.");
 
@@ -284,7 +290,7 @@ START_TEST(test_some)
     struct sec_TCP_con *con3 = new_TCP_con(tcp_s, mono_time);
 
     uint8_t requ_p[1 + CRYPTO_PUBLIC_KEY_SIZE];
-    requ_p[0] = 0;
+    requ_p[0] = TCP_PACKET_ROUTING_REQUEST;
 
     // Sending wrong public keys to test server response.
     memcpy(requ_p + 1, con3->public_key, CRYPTO_PUBLIC_KEY_SIZE);
@@ -298,14 +304,14 @@ START_TEST(test_some)
     uint8_t data[2048];
     int len = read_packet_sec_TCP(con1, data, 2 + 1 + 1 + CRYPTO_PUBLIC_KEY_SIZE + CRYPTO_MAC_SIZE);
     ck_assert_msg(len == 1 + 1 + CRYPTO_PUBLIC_KEY_SIZE, "Wrong response packet length of %d.", len);
-    ck_assert_msg(data[0] == 1, "Wrong response packet id of %d.", data[0]);
+    ck_assert_msg(data[0] == TCP_PACKET_ROUTING_RESPONSE, "Wrong response packet id of %d.", data[0]);
     ck_assert_msg(data[1] == 16, "Server didn't refuse connection using wrong public key.");
     ck_assert_msg(public_key_cmp(data + 2, con3->public_key) == 0, "Key in response packet wrong.");
 
     // Connection 3
     len = read_packet_sec_TCP(con3, data, 2 + 1 + 1 + CRYPTO_PUBLIC_KEY_SIZE + CRYPTO_MAC_SIZE);
     ck_assert_msg(len == 1 + 1 + CRYPTO_PUBLIC_KEY_SIZE, "Wrong response packet length of %d.", len);
-    ck_assert_msg(data[0] == 1, "Wrong response packet id of %d.", data[0]);
+    ck_assert_msg(data[0] == TCP_PACKET_ROUTING_RESPONSE, "Wrong response packet id of %d.", data[0]);
     ck_assert_msg(data[1] == 16, "Server didn't refuse connection using wrong public key.");
     ck_assert_msg(public_key_cmp(data + 2, con1->public_key) == 0, "Key in response packet wrong.");
 
@@ -319,11 +325,11 @@ START_TEST(test_some)
 
     len = read_packet_sec_TCP(con1, data, 2 + 2 + CRYPTO_MAC_SIZE);
     ck_assert_msg(len == 2, "wrong len %d", len);
-    ck_assert_msg(data[0] == 2, "wrong packet id %u", data[0]);
+    ck_assert_msg(data[0] == TCP_PACKET_CONNECTION_NOTIFICATION, "wrong packet id %u", data[0]);
     ck_assert_msg(data[1] == 16, "wrong peer id %u", data[1]);
     len = read_packet_sec_TCP(con3, data, 2 + 2 + CRYPTO_MAC_SIZE);
     ck_assert_msg(len == 2, "wrong len %d", len);
-    ck_assert_msg(data[0] == 2, "wrong packet id %u", data[0]);
+    ck_assert_msg(data[0] == TCP_PACKET_CONNECTION_NOTIFICATION, "wrong packet id %u", data[0]);
     ck_assert_msg(data[1] == 16, "wrong peer id %u", data[1]);
     len = read_packet_sec_TCP(con1, data, 2 + sizeof(test_packet) + CRYPTO_MAC_SIZE);
     ck_assert_msg(len == sizeof(test_packet), "wrong len %d", len);
@@ -354,14 +360,14 @@ START_TEST(test_some)
     ck_assert_msg(memcmp(data, test_packet, sizeof(test_packet)) == 0, "packet is wrong %u %u %u %u", data[0], data[1],
                   data[sizeof(test_packet) - 2], data[sizeof(test_packet) - 1]);
 
-    uint8_t ping_packet[1 + sizeof(uint64_t)] = {4, 8, 6, 9, 67};
+    uint8_t ping_packet[1 + sizeof(uint64_t)] = {TCP_PACKET_PING, 8, 6, 9, 67};
     write_packet_TCP_secure_connection(con1, ping_packet, sizeof(ping_packet));
 
     do_TCP_server_delay(tcp_s, mono_time, 50);
 
     len = read_packet_sec_TCP(con1, data, 2 + sizeof(ping_packet) + CRYPTO_MAC_SIZE);
     ck_assert_msg(len == sizeof(ping_packet), "wrong len %d", len);
-    ck_assert_msg(data[0] == 5, "wrong packet id %u", data[0]);
+    ck_assert_msg(data[0] == TCP_PACKET_PONG, "wrong packet id %u", data[0]);
     ck_assert_msg(memcmp(ping_packet + 1, data + 1, sizeof(uint64_t)) == 0, "wrong packet data");
 
     // Kill off the connections
@@ -370,6 +376,7 @@ START_TEST(test_some)
     kill_TCP_con(con2);
     kill_TCP_con(con3);
 
+    logger_kill(logger);
     mono_time_free(mono_time);
 }
 END_TEST
@@ -458,11 +465,12 @@ static int oob_data_callback(void *object, const uint8_t *public_key, const uint
 START_TEST(test_client)
 {
     Mono_Time *mono_time = mono_time_new();
+    Logger *logger = logger_new();
 
     uint8_t self_public_key[CRYPTO_PUBLIC_KEY_SIZE];
     uint8_t self_secret_key[CRYPTO_SECRET_KEY_SIZE];
     crypto_new_keypair(self_public_key, self_secret_key);
-    TCP_Server *tcp_s = new_TCP_server(USE_IPV6, NUM_PORTS, ports, self_secret_key, nullptr);
+    TCP_Server *tcp_s = new_TCP_server(logger, USE_IPV6, NUM_PORTS, ports, self_secret_key, nullptr);
     ck_assert_msg(tcp_s != nullptr, "Failed to create a TCP relay server.");
     ck_assert_msg(tcp_server_listen_count(tcp_s) == NUM_PORTS, "Failed to bind the relay server to all ports.");
 
@@ -476,7 +484,7 @@ START_TEST(test_client)
 
     TCP_Client_Connection *conn = new_TCP_connection(mono_time, ip_port_tcp_s, self_public_key, f_public_key, f_secret_key,
                                   nullptr);
-    do_TCP_connection(mono_time, conn, nullptr);
+    do_TCP_connection(logger, mono_time, conn, nullptr);
     c_sleep(50);
 
     // The connection status should be unconfirmed here because we have finished
@@ -490,7 +498,7 @@ START_TEST(test_client)
 
     for (uint8_t i = 0; i < LOOP_SIZE; i++) {
         mono_time_update(mono_time);
-        do_TCP_connection(mono_time, conn, nullptr); // Run the connection loop.
+        do_TCP_connection(logger, mono_time, conn, nullptr); // Run the connection loop.
 
         // The status of the connection should continue to be TCP_CLIENT_CONFIRMED after multiple subsequent do_TCP_connection() calls.
         ck_assert_msg(tcp_con_status(conn) == TCP_CLIENT_CONFIRMED, "Wrong connection status. Expected: %d, is: %d",
@@ -524,13 +532,13 @@ START_TEST(test_client)
     // These integers will increment per successful callback.
     oob_data_callback_good = response_callback_good = status_callback_good = data_callback_good = 0;
 
-    do_TCP_connection(mono_time, conn, nullptr);
-    do_TCP_connection(mono_time, conn2, nullptr);
+    do_TCP_connection(logger, mono_time, conn, nullptr);
+    do_TCP_connection(logger, mono_time, conn2, nullptr);
 
     do_TCP_server_delay(tcp_s, mono_time, 50);
 
-    do_TCP_connection(mono_time, conn, nullptr);
-    do_TCP_connection(mono_time, conn2, nullptr);
+    do_TCP_connection(logger, mono_time, conn, nullptr);
+    do_TCP_connection(logger, mono_time, conn2, nullptr);
     c_sleep(50);
 
     uint8_t data[5] = {1, 2, 3, 4, 5};
@@ -541,8 +549,8 @@ START_TEST(test_client)
 
     do_TCP_server_delay(tcp_s, mono_time, 50);
 
-    do_TCP_connection(mono_time, conn, nullptr);
-    do_TCP_connection(mono_time, conn2, nullptr);
+    do_TCP_connection(logger, mono_time, conn, nullptr);
+    do_TCP_connection(logger, mono_time, conn2, nullptr);
 
     // All callback methods save data should have run during the above network prodding.
     ck_assert_msg(oob_data_callback_good == 1, "OOB callback not called");
@@ -559,16 +567,16 @@ START_TEST(test_client)
 
     do_TCP_server_delay(tcp_s, mono_time, 50);
 
-    do_TCP_connection(mono_time, conn, nullptr);
-    do_TCP_connection(mono_time, conn2, nullptr);
+    do_TCP_connection(logger, mono_time, conn, nullptr);
+    do_TCP_connection(logger, mono_time, conn2, nullptr);
     ck_assert_msg(data_callback_good == 1, "Data callback was not called.");
     status_callback_good = 0;
     send_disconnect_request(conn2, 0);
 
     do_TCP_server_delay(tcp_s, mono_time, 50);
 
-    do_TCP_connection(mono_time, conn, nullptr);
-    do_TCP_connection(mono_time, conn2, nullptr);
+    do_TCP_connection(logger, mono_time, conn, nullptr);
+    do_TCP_connection(logger, mono_time, conn2, nullptr);
     ck_assert_msg(status_callback_good == 1, "Status callback not called");
     ck_assert_msg(status_callback_status == 1, "Wrong status callback status.");
 
@@ -577,6 +585,7 @@ START_TEST(test_client)
     kill_TCP_connection(conn);
     kill_TCP_connection(conn2);
 
+    logger_kill(logger);
     mono_time_free(mono_time);
 }
 END_TEST
@@ -585,6 +594,7 @@ END_TEST
 START_TEST(test_client_invalid)
 {
     Mono_Time *mono_time = mono_time_new();
+    Logger *logger = logger_new();
 
     uint8_t self_public_key[CRYPTO_PUBLIC_KEY_SIZE];
     uint8_t self_secret_key[CRYPTO_SECRET_KEY_SIZE];
@@ -602,7 +612,7 @@ START_TEST(test_client_invalid)
 
     // Run the client's main loop but not the server.
     mono_time_update(mono_time);
-    do_TCP_connection(mono_time, conn, nullptr);
+    do_TCP_connection(logger, mono_time, conn, nullptr);
     c_sleep(50);
 
     // After 50ms of no response...
@@ -611,18 +621,19 @@ START_TEST(test_client_invalid)
     // After 5s...
     c_sleep(5000);
     mono_time_update(mono_time);
-    do_TCP_connection(mono_time, conn, nullptr);
+    do_TCP_connection(logger, mono_time, conn, nullptr);
     ck_assert_msg(tcp_con_status(conn) == TCP_CLIENT_CONNECTING, "Wrong status. Expected: %d, is: %d.",
                   TCP_CLIENT_CONNECTING, tcp_con_status(conn));
     // 11s... (Should wait for 10 before giving up.)
     c_sleep(6000);
     mono_time_update(mono_time);
-    do_TCP_connection(mono_time, conn, nullptr);
+    do_TCP_connection(logger, mono_time, conn, nullptr);
     ck_assert_msg(tcp_con_status(conn) == TCP_CLIENT_DISCONNECTED, "Wrong status. Expected: %d, is: %d.",
                   TCP_CLIENT_DISCONNECTED, tcp_con_status(conn));
 
     kill_TCP_connection(conn);
 
+    logger_kill(logger);
     mono_time_free(mono_time);
 }
 END_TEST
@@ -656,12 +667,13 @@ static int tcp_data_callback(void *object, int id, const uint8_t *data, uint16_t
 START_TEST(test_tcp_connection)
 {
     Mono_Time *mono_time = mono_time_new();
+    Logger *logger = logger_new();
 
     tcp_data_callback_called = 0;
     uint8_t self_public_key[CRYPTO_PUBLIC_KEY_SIZE];
     uint8_t self_secret_key[CRYPTO_SECRET_KEY_SIZE];
     crypto_new_keypair(self_public_key, self_secret_key);
-    TCP_Server *tcp_s = new_TCP_server(USE_IPV6, NUM_PORTS, ports, self_secret_key, nullptr);
+    TCP_Server *tcp_s = new_TCP_server(logger, USE_IPV6, NUM_PORTS, ports, self_secret_key, nullptr);
     ck_assert_msg(public_key_cmp(tcp_server_public_key(tcp_s), self_public_key) == 0, "Wrong public key");
 
     TCP_Proxy_Info proxy_info;
@@ -695,18 +707,18 @@ START_TEST(test_tcp_connection)
 
     do_TCP_server_delay(tcp_s, mono_time, 50);
 
-    do_tcp_connections(tc_1, nullptr);
-    do_tcp_connections(tc_2, nullptr);
+    do_tcp_connections(logger, tc_1, nullptr);
+    do_tcp_connections(logger, tc_2, nullptr);
 
     do_TCP_server_delay(tcp_s, mono_time, 50);
 
-    do_tcp_connections(tc_1, nullptr);
-    do_tcp_connections(tc_2, nullptr);
+    do_tcp_connections(logger, tc_1, nullptr);
+    do_tcp_connections(logger, tc_2, nullptr);
 
     do_TCP_server_delay(tcp_s, mono_time, 50);
 
-    do_tcp_connections(tc_1, nullptr);
-    do_tcp_connections(tc_2, nullptr);
+    do_tcp_connections(logger, tc_1, nullptr);
+    do_tcp_connections(logger, tc_2, nullptr);
 
     int ret = send_packet_tcp_connection(tc_1, 0, (const uint8_t *)"Gentoo", 6);
     ck_assert_msg(ret == 0, "could not send packet.");
@@ -714,8 +726,8 @@ START_TEST(test_tcp_connection)
 
     do_TCP_server_delay(tcp_s, mono_time, 50);
 
-    do_tcp_connections(tc_1, nullptr);
-    do_tcp_connections(tc_2, nullptr);
+    do_tcp_connections(logger, tc_1, nullptr);
+    do_tcp_connections(logger, tc_2, nullptr);
 
     ck_assert_msg(tcp_data_callback_called, "could not recv packet.");
     ck_assert_msg(tcp_connection_to_online_tcp_relays(tc_1, 0) == 1, "Wrong number of connected relays");
@@ -723,8 +735,8 @@ START_TEST(test_tcp_connection)
 
     do_TCP_server_delay(tcp_s, mono_time, 50);
 
-    do_tcp_connections(tc_1, nullptr);
-    do_tcp_connections(tc_2, nullptr);
+    do_tcp_connections(logger, tc_1, nullptr);
+    do_tcp_connections(logger, tc_2, nullptr);
 
     ck_assert_msg(send_packet_tcp_connection(tc_1, 0, (const uint8_t *)"Gentoo", 6) == -1, "could send packet.");
     ck_assert_msg(kill_tcp_connection_to(tc_2, 0) == 0, "could not kill connection to\n");
@@ -733,6 +745,7 @@ START_TEST(test_tcp_connection)
     kill_tcp_connections(tc_1);
     kill_tcp_connections(tc_2);
 
+    logger_kill(logger);
     mono_time_free(mono_time);
 }
 END_TEST
@@ -761,6 +774,7 @@ static int tcp_oobdata_callback(void *object, const uint8_t *public_key, unsigne
 START_TEST(test_tcp_connection2)
 {
     Mono_Time *mono_time = mono_time_new();
+    Logger *logger = logger_new();
 
     tcp_oobdata_callback_called = 0;
     tcp_data_callback_called = 0;
@@ -768,7 +782,7 @@ START_TEST(test_tcp_connection2)
     uint8_t self_public_key[CRYPTO_PUBLIC_KEY_SIZE];
     uint8_t self_secret_key[CRYPTO_SECRET_KEY_SIZE];
     crypto_new_keypair(self_public_key, self_secret_key);
-    TCP_Server *tcp_s = new_TCP_server(USE_IPV6, NUM_PORTS, ports, self_secret_key, nullptr);
+    TCP_Server *tcp_s = new_TCP_server(logger, USE_IPV6, NUM_PORTS, ports, self_secret_key, nullptr);
     ck_assert_msg(public_key_cmp(tcp_server_public_key(tcp_s), self_public_key) == 0, "Wrong public key");
 
     TCP_Proxy_Info proxy_info;
@@ -796,18 +810,18 @@ START_TEST(test_tcp_connection2)
 
     do_TCP_server_delay(tcp_s, mono_time, 50);
 
-    do_tcp_connections(tc_1, nullptr);
-    do_tcp_connections(tc_2, nullptr);
+    do_tcp_connections(logger, tc_1, nullptr);
+    do_tcp_connections(logger, tc_2, nullptr);
 
     do_TCP_server_delay(tcp_s, mono_time, 50);
 
-    do_tcp_connections(tc_1, nullptr);
-    do_tcp_connections(tc_2, nullptr);
+    do_tcp_connections(logger, tc_1, nullptr);
+    do_tcp_connections(logger, tc_2, nullptr);
 
     do_TCP_server_delay(tcp_s, mono_time, 50);
 
-    do_tcp_connections(tc_1, nullptr);
-    do_tcp_connections(tc_2, nullptr);
+    do_tcp_connections(logger, tc_1, nullptr);
+    do_tcp_connections(logger, tc_2, nullptr);
 
     int ret = send_packet_tcp_connection(tc_1, 0, (const uint8_t *)"Gentoo", 6);
     ck_assert_msg(ret == 0, "could not send packet.");
@@ -816,15 +830,15 @@ START_TEST(test_tcp_connection2)
 
     do_TCP_server_delay(tcp_s, mono_time, 50);
 
-    do_tcp_connections(tc_1, nullptr);
-    do_tcp_connections(tc_2, nullptr);
+    do_tcp_connections(logger, tc_1, nullptr);
+    do_tcp_connections(logger, tc_2, nullptr);
 
     ck_assert_msg(tcp_oobdata_callback_called, "could not recv packet.");
 
     do_TCP_server_delay(tcp_s, mono_time, 50);
 
-    do_tcp_connections(tc_1, nullptr);
-    do_tcp_connections(tc_2, nullptr);
+    do_tcp_connections(logger, tc_1, nullptr);
+    do_tcp_connections(logger, tc_2, nullptr);
 
     ck_assert_msg(tcp_data_callback_called, "could not recv packet.");
     ck_assert_msg(kill_tcp_connection_to(tc_1, 0) == 0, "could not kill connection to\n");
@@ -833,6 +847,7 @@ START_TEST(test_tcp_connection2)
     kill_tcp_connections(tc_1);
     kill_tcp_connections(tc_2);
 
+    logger_kill(logger);
     mono_time_free(mono_time);
 }
 END_TEST
