@@ -1,8 +1,12 @@
-#ifndef _XOPEN_SOURCE
-#define _XOPEN_SOURCE 600
+#ifdef HAVE_CONFIG_H
+#include "config.h"
 #endif
 
-#include "helpers.h"
+#include <stdio.h>
+#include <string.h>
+
+#include "../testing/misc_tools.h"
+#include "../toxcore/ccompat.h"
 
 int main(void)
 {
@@ -10,17 +14,17 @@ int main(void)
     Tox *tox1 = tox_new_log_lan(nullptr, nullptr, nullptr, /* lan_discovery */true);
     Tox *tox2 = tox_new_log_lan(nullptr, nullptr, nullptr, /* lan_discovery */true);
 
-    printf("Waiting for LAN discovery");
+    printf("Waiting for LAN discovery. This loop will attempt to run until successful.");
 
-    while (tox_self_get_connection_status(tox1) == TOX_CONNECTION_NONE ||
-            tox_self_get_connection_status(tox2) == TOX_CONNECTION_NONE) {
+    do {
         printf(".");
         fflush(stdout);
 
         tox_iterate(tox1, nullptr);
         tox_iterate(tox2, nullptr);
         c_sleep(1000);
-    }
+    } while (tox_self_get_connection_status(tox1) == TOX_CONNECTION_NONE ||
+             tox_self_get_connection_status(tox2) == TOX_CONNECTION_NONE);
 
     printf(" %d <-> %d\n",
            tox_self_get_connection_status(tox1),
