@@ -24,16 +24,16 @@
 
 // TODO(zoff99): don't hardcode this, let the application choose it
 // VPX Info: Time to spend encoding, in microseconds (it's a *soft* deadline)
-#define WANTED_MAX_ENCODER_FPS (40)
+#define WANTED_MAX_ENCODER_FPS 40
 #define MAX_ENCODE_TIME_US (1000000 / WANTED_MAX_ENCODER_FPS) // to allow x fps
 
 #define VIDEO_SEND_X_KEYFRAMES_FIRST 7 // force the first n frames to be keyframes!
 
 /*
-VPX_DL_REALTIME       (1)       deadline parameter analogous to VPx REALTIME mode.
-VPX_DL_GOOD_QUALITY   (1000000) deadline parameter analogous to VPx GOOD QUALITY mode.
-VPX_DL_BEST_QUALITY   (0)       deadline parameter analogous to VPx BEST QUALITY mode.
-*/
+ * VPX_DL_REALTIME       (1)       deadline parameter analogous to VPx REALTIME mode.
+ * VPX_DL_GOOD_QUALITY   (1000000) deadline parameter analogous to VPx GOOD QUALITY mode.
+ * VPX_DL_BEST_QUALITY   (0)       deadline parameter analogous to VPx BEST QUALITY mode.
+ */
 
 typedef struct ToxAVCall_s {
     ToxAV *av;
@@ -755,7 +755,7 @@ bool toxav_audio_send_frame(ToxAV *av, uint32_t friend_number, const int16_t *pc
         goto RETURN;
     }
 
-    { /* Encode and send */
+    {   /* Encode and send */
         if (ac_reconfigure_encoder(call->audio, call->audio_bit_rate * 1000, sampling_rate, channels) != 0) {
             pthread_mutex_unlock(call->mutex_audio);
             rc = TOXAV_ERR_SEND_FRAME_INVALID;
@@ -896,7 +896,7 @@ bool toxav_video_send_frame(ToxAV *av, uint32_t friend_number, uint16_t width, u
 
     // we start with I-frames (full frames) and then switch to normal mode later
 
-    { /* Encode */
+    {   /* Encode */
         vpx_image_t img;
         img.w = 0;
         img.h = 0;
@@ -1302,7 +1302,7 @@ static bool call_prepare_transmission(ToxAVCall *call)
 
     ToxAV *av = call->av;
 
-    if (!av->acb && !av->vcb) {
+    if (av->acb == nullptr && av->vcb == nullptr) {
         /* It makes no sense to have CSession without callbacks */
         return false;
     }
@@ -1323,10 +1323,15 @@ static bool call_prepare_transmission(ToxAVCall *call)
     /* Prepare bwc */
     call->bwc = bwc_new(av->m, av->tox, call->friend_number, callback_bwc, call, av->toxav_mono_time);
 
-    { /* Prepare audio */
+    if (call->bwc == nullptr) {
+        LOGGER_ERROR(av->m->log, "Failed to create new bwc");
+        goto FAILURE;
+    }
+
+    {   /* Prepare audio */
         call->audio = ac_new(av->toxav_mono_time, av->m->log, av, call->friend_number, av->acb, av->acb_user_data);
 
-        if (!call->audio) {
+        if (call->audio == nullptr) {
             LOGGER_ERROR(av->m->log, "Failed to create audio codec session");
             goto FAILURE;
         }
@@ -1334,15 +1339,16 @@ static bool call_prepare_transmission(ToxAVCall *call)
         call->audio_rtp = rtp_new(RTP_TYPE_AUDIO, av->m, av->tox, call->friend_number, call->bwc,
                                   call->audio, ac_queue_message);
 
-        if (!call->audio_rtp) {
+        if (call->audio_rtp == nullptr) {
             LOGGER_ERROR(av->m->log, "Failed to create audio rtp session");
             goto FAILURE;
         }
     }
-    { /* Prepare video */
+
+    {   /* Prepare video */
         call->video = vc_new(av->toxav_mono_time, av->m->log, av, call->friend_number, av->vcb, av->vcb_user_data);
 
-        if (!call->video) {
+        if (call->video == nullptr) {
             LOGGER_ERROR(av->m->log, "Failed to create video codec session");
             goto FAILURE;
         }
@@ -1350,7 +1356,7 @@ static bool call_prepare_transmission(ToxAVCall *call)
         call->video_rtp = rtp_new(RTP_TYPE_VIDEO, av->m, av->tox, call->friend_number, call->bwc,
                                   call->video, vc_queue_message);
 
-        if (!call->video_rtp) {
+        if (call->video_rtp == nullptr) {
             LOGGER_ERROR(av->m->log, "Failed to create video rtp session");
             goto FAILURE;
         }
