@@ -1,25 +1,10 @@
-/*
- * Logger abstraction backed by callbacks for writing.
+/* SPDX-License-Identifier: GPL-3.0-or-later
+ * Copyright © 2016-2018 The TokTok team.
+ * Copyright © 2013 Tox project.
  */
 
 /*
- * Copyright © 2016-2018 The TokTok team.
- * Copyright © 2013 Tox project.
- *
- * This file is part of Tox, the free peer to peer instant messenger.
- *
- * Tox is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * Tox is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Tox.  If not, see <http://www.gnu.org/licenses/>.
+ * Logger abstraction backed by callbacks for writing.
  */
 #ifndef C_TOXCORE_TOXCORE_LOGGER_H
 #define C_TOXCORE_TOXCORE_LOGGER_H
@@ -38,7 +23,7 @@ typedef enum Logger_Level {
     LOGGER_LEVEL_DEBUG,
     LOGGER_LEVEL_INFO,
     LOGGER_LEVEL_WARNING,
-    LOGGER_LEVEL_ERROR
+    LOGGER_LEVEL_ERROR,
 } Logger_Level;
 
 typedef struct Logger Logger;
