@@ -21,7 +21,7 @@
 #include "util.h"
 
 /* defines for the array size and
-   timeout for onion announce packets. */
+ * timeout for onion announce packets. */
 #define ANNOUNCE_ARRAY_SIZE 256
 #define ANNOUNCE_TIMEOUT 10
 
@@ -97,6 +97,7 @@ typedef struct Onion_Data_Handler {
 
 struct Onion_Client {
     Mono_Time *mono_time;
+    const Logger *logger;
 
     DHT     *dht;
     Net_Crypto *c;
@@ -610,7 +611,8 @@ typedef struct Onion_Client_Cmp_data {
 
 static int onion_client_cmp_entry(const void *a, const void *b)
 {
-    Onion_Client_Cmp_data cmp1, cmp2;
+    Onion_Client_Cmp_data cmp1;
+    Onion_Client_Cmp_data cmp2;
     memcpy(&cmp1, a, sizeof(Onion_Client_Cmp_data));
     memcpy(&cmp2, b, sizeof(Onion_Client_Cmp_data));
     Onion_Node entry1 = cmp1.entry;
@@ -700,7 +702,8 @@ static int client_add_to_list(Onion_Client *onion_c, uint32_t num, const uint8_t
 
     sort_onion_node_list(list_nodes, list_length, onion_c->mono_time, reference_id);
 
-    int index = -1, stored = 0;
+    int index = -1;
+    int stored = 0;
     unsigned int i;
 
     if (onion_node_timed_out(&list_nodes[0], onion_c->mono_time)
@@ -1045,10 +1048,12 @@ int send_onion_data(Onion_Client *onion_c, int friend_num, const uint8_t *data,
         return -1;
     }
 
-    unsigned int i, good_nodes[MAX_ONION_CLIENTS], num_good = 0, num_nodes = 0;
+    unsigned int good_nodes[MAX_ONION_CLIENTS];
+    unsigned int num_good = 0;
+    unsigned int num_nodes = 0;
     Onion_Node *list_nodes = onion_c->friends_list[friend_num].clients_list;
 
-    for (i = 0; i < MAX_ONION_CLIENTS; ++i) {
+    for (unsigned int i = 0; i < MAX_ONION_CLIENTS; ++i) {
         if (onion_node_timed_out(&list_nodes[i], onion_c->mono_time)) {
             continue;
         }
@@ -1080,7 +1085,7 @@ int send_onion_data(Onion_Client *onion_c, int friend_num, const uint8_t *data,
 
     unsigned int good = 0;
 
-    for (i = 0; i < num_good; ++i) {
+    for (unsigned int i = 0; i < num_good; ++i) {
         Onion_Path path;
 
         if (random_path(onion_c, &onion_c->onion_paths_friends, -1, &path) == -1) {
@@ -1209,7 +1214,8 @@ static int send_dhtpk_announce(Onion_Client *onion_c, uint16_t friend_num, uint8
         }
     }
 
-    int num1 = -1, num2 = -1;
+    int num1 = -1;
+    int num2 = -1;
 
     if (onion_dht_both != 1) {
         num1 = send_onion_data(onion_c, friend_num, data, DHTPK_DATA_MIN_LENGTH + nodes_len);
@@ -1288,9 +1294,9 @@ int onion_addfriend(Onion_Client *onion_c, const uint8_t *public_key)
         return num;
     }
 
-    unsigned int i, index = -1;
+    unsigned int index = -1;
 
-    for (i = 0; i < onion_c->num_friends; ++i) {
+    for (unsigned int i = 0; i < onion_c->num_friends; ++i) {
         if (onion_c->friends_list[i].status == 0) {
             index = i;
             break;
@@ -1658,10 +1664,10 @@ void oniondata_registerhandler(Onion_Client *onion_c, uint8_t byte, oniondata_ha
 
 static void do_announce(Onion_Client *onion_c)
 {
-    unsigned int i, count = 0;
+    unsigned int count = 0;
     Onion_Node *list_nodes = onion_c->clients_announce_list;
 
-    for (i = 0; i < MAX_ONION_CLIENTS_ANNOUNCE; ++i) {
+    for (unsigned int i = 0; i < MAX_ONION_CLIENTS_ANNOUNCE; ++i) {
         if (onion_node_timed_out(&list_nodes[i], onion_c->mono_time)) {
             continue;
         }
@@ -1734,7 +1740,7 @@ static void do_announce(Onion_Client *onion_c)
 
         if (count <= random_u32() % MAX_ONION_CLIENTS_ANNOUNCE) {
             if (num_nodes != 0) {
-                for (i = 0; i < (MAX_ONION_CLIENTS_ANNOUNCE / 2); ++i) {
+                for (unsigned int i = 0; i < (MAX_ONION_CLIENTS_ANNOUNCE / 2); ++i) {
                     const uint32_t num = random_u32() % num_nodes;
                     client_send_announce_request(onion_c, 0, path_nodes[num].ip_port, path_nodes[num].public_key, nullptr, -1);
                 }
@@ -1748,7 +1754,8 @@ static void do_announce(Onion_Client *onion_c)
  */
 static int onion_isconnected(const Onion_Client *onion_c)
 {
-    unsigned int i, num = 0, announced = 0;
+    unsigned int num = 0;
+    unsigned int announced = 0;
 
     if (mono_time_is_timeout(onion_c->mono_time, onion_c->last_packet_recv, ONION_OFFLINE_TIMEOUT)) {
         return 0;
@@ -1758,7 +1765,7 @@ static int onion_isconnected(const Onion_Client *onion_c)
         return 0;
     }
 
-    for (i = 0; i < MAX_ONION_CLIENTS_ANNOUNCE; ++i) {
+    for (unsigned int i = 0; i < MAX_ONION_CLIENTS_ANNOUNCE; ++i) {
         if (!onion_node_timed_out(&onion_c->clients_announce_list[i], onion_c->mono_time)) {
             ++num;
 
@@ -1775,7 +1782,7 @@ static int onion_isconnected(const Onion_Client *onion_c)
     }
 
     /* Consider ourselves online if we are announced to half or more nodes
-       we are connected to */
+     * we are connected to */
     if (num && announced) {
         if ((num / 2) <= announced && (pnodes / 2) <= num) {
             return 1;
@@ -1827,15 +1834,12 @@ void do_onion_client(Onion_Client *onion_c)
         }
     }
 
-    bool udp_connected = dht_non_lan_connected(onion_c->dht);
+    onion_c->udp_connected = dht_non_lan_connected(onion_c->dht);
 
     if (mono_time_is_timeout(onion_c->mono_time, onion_c->first_run, ONION_CONNECTION_SECONDS * 2)) {
-        set_tcp_onion_status(nc_get_tcp_c(onion_c->c), !udp_connected);
+        set_tcp_onion_status(nc_get_tcp_c(onion_c->c), !onion_c->udp_connected);
     }
 
-    onion_c->udp_connected = udp_connected
-                             || get_random_tcp_onion_conn_number(nc_get_tcp_c(onion_c->c)) == -1; /* Check if connected to any TCP relays. */
-
     if (onion_connection_status(onion_c)) {
         for (unsigned i = 0; i < onion_c->num_friends; ++i) {
             do_friend(onion_c, i);
@@ -1849,7 +1853,7 @@ void do_onion_client(Onion_Client *onion_c)
     onion_c->last_run = mono_time_get(onion_c->mono_time);
 }
 
-Onion_Client *new_onion_client(Mono_Time *mono_time, Net_Crypto *c)
+Onion_Client *new_onion_client(const Logger *logger, Mono_Time *mono_time, Net_Crypto *c)
 {
     if (c == nullptr) {
         return nullptr;
@@ -1869,6 +1873,7 @@ Onion_Client *new_onion_client(Mono_Time *mono_time, Net_Crypto *c)
     }
 
     onion_c->mono_time = mono_time;
+    onion_c->logger = logger;
     onion_c->dht = nc_get_dht(c);
     onion_c->net = dht_get_net(onion_c->dht);
     onion_c->c = c;
