@@ -7,6 +7,7 @@
 
 #define SET_ERROR_PARAMETER(param, x) do { if (param) { *param = x; } } while (0)
 
+//!TOKSTYLE-
 
 #define CONST_FUNCTION(lowercase, uppercase) \
 uint32_t tox_##lowercase(void) \
@@ -58,6 +59,9 @@ ACCESSORS(size_t, savedata_, length)
 ACCESSORS(tox_log_cb *, log_, callback)
 ACCESSORS(void *, log_, user_data)
 ACCESSORS(bool,, local_discovery_enabled)
+ACCESSORS(bool,, experimental_thread_safety)
+
+//!TOKSTYLE+
 
 const uint8_t *tox_options_get_savedata_data(const struct Tox_Options *options)
 {
@@ -80,6 +84,7 @@ void tox_options_default(struct Tox_Options *options)
         tox_options_set_proxy_type(options, TOX_PROXY_TYPE_NONE);
         tox_options_set_hole_punching_enabled(options, true);
         tox_options_set_local_discovery_enabled(options, true);
+        tox_options_set_experimental_thread_safety(options, false);
     }
 }
 
